import React, {
  useState,
  useCallback,
  useEffect,
} from 'react';
import { scaleSequential, interpolateYlOrRd, max } from 'd3';
import ReactDOM from 'react-dom';
import { useUSA } from './useUSA';
import { Marks } from './Marks';
import { useData } from './useData';

const width = 960;
const height = 500;

const App = () => {
  const data = useUSA();
  const educationData = useData();

  if (!data || !educationData) {
    return <pre>Loading...</pre>;
  }
	console.log(data);
  
  const fipToScore = new Map();
educationData.forEach( d => {
	fipToScore.set(d.fips, d.bachelorsOrHigher);
});
  console.log(fipToScore);
  const colorValue = d => d.bachelorsOrHigher;
  
  const colorScale = scaleSequential(interpolateYlOrRd)
  		.domain([0, max(educationData, colorValue)]);
 
  return (
    <svg width={width} height={height}>
        <Marks 
          data={data}
          educationData={educationData}
          fipToScore={fipToScore}
          colorValue={colorValue}
          colorScale={colorScale}
          
          />
    </svg>
  );
};

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
